@@ -4,7 +4,7 @@ use Catmandu::Util qw(:io :is :check);
 use PICA::Schema;
 use Moo;
 
-our $VERSION = '0.26';
+our $VERSION = '1.00';
 
 with qw(Catmandu::Validator);
 
@@ -15,25 +15,41 @@ has schema => (
         my ($self, $schema) = @_;
         unless (is_instance($schema, 'PICA::Schema')) {
             if (is_string($schema)) {
-                $schema = read_json($schema);
+                if ($schema =~ /\.y.?ml/) {
+                    $schema = read_yaml($schema);
+                } else {
+                    $schema = read_json($schema);
+                }
             }
             $self->{schema} = PICA::Schema->new(check_hash_ref($schema));
         }
     }
 );
 
-has ignore_unknown_fields => ( is => 'ro' );
-has ignore_unknown_subfields => ( is => 'ro' );
-has ignore_subfield_order => ( is => 'ro' );
+has ignore_unknown_fields      => ( is => 'ro' );
+has ignore_unknown_subfields   => ( is => 'ro' );
+has ignore_unknown             => ( is => 'ro' );
+has allow_deprecated_fields    => ( is => 'ro' );
+has allow_deprecated_subfields => ( is => 'ro' );
+has allow_deprecated_codes     => ( is => 'ro' );
+has allow_deprecated           => ( is => 'ro' );
+has ignore_subfield_order      => ( is => 'ro' );
+has ignore_subfields           => ( is => 'ro' );
 
 has options => (
     is => 'ro',
     init_arg => undef,
     builder => sub {
         return {
-            ignore_unknown_fields    => $_[0]->ignore_unknown_fields,
-            ignore_unknown_subfields => $_[0]->ignore_unknown_subfields,
-            ignore_subfield_order    => $_[0]->ignore_subfield_order,
+            ignore_unknown_fields      => $_[0]->ignore_unknown_fields,
+            ignore_unknown_subfields   => $_[0]->ignore_unknown_subfields,
+            ignore_unknown             => $_[0]->ignore_unknown,
+            allow_deprecated_fields    => $_[0]->allow_deprecated_fields,
+            allow_deprecated_subfields => $_[0]->allow_deprecated_subfields,
+            allow_deprecated_codes     => $_[0]->allow_deprecated_codes,
+            allow_deprecated           => $_[0]->allow_deprecated,
+            ignore_subfield_order      => $_[0]->ignore_subfield_order,
+            ignore_subfields           => $_[0]->ignore_subfields,
         }
     },
 );
@@ -41,7 +57,7 @@ has options => (
 sub validate_data {
     my ($self, $record) = @_;
 
-    my @errors = $self->schema->check($record, %{$self->options});
+    my @errors = $self->{schema}->check($record, %{$self->options});
 
     return @errors ? \@errors : undef;
 }
@@ -67,7 +83,7 @@ In Perl code:
         unless($validator->validate($record)){
             say "$_" for @{$validator->last_errors()};
         }
-    }});
+    });
 
 In Catmandu Fix language:
 
@@ -88,7 +104,7 @@ usage of validators in Catmandu Fix language.
 
 =item schema
 
-Avram Schema given as hash reference, filename (JSON), or instance of
+Avram Schema given as hash reference, filename (JSON or YAML), or instance of
 L<PICA::Schema>.
 
 =item ignore_unknown_fields
@@ -99,9 +115,33 @@ Don't report fields not included in the schema.
 
 Don't report subfields not included in the schema.
 
+=item ignore_unknown
+
+Don't report fields and subfields not included in the schema.
+
+=item allow_deprecated_fields
+
+Don't report deprecated fields.
+
+=item allow_deprecated_subfields
+
+Don't report deprecated subfields.
+
+=item allow_deprecated_codes
+
+Don't report deprecated codes.
+
+=item allow_deprecated
+
+Don't report deprecated fields, subfields, and codes.
+
 =item ignore_subfield_order
 
-Don't report subfields in wrong order.
+Don't report errors resulting on wrong subfield order.
+
+=item ignore_subfields
+
+Don't check subfields at all.
 
 =back
 
